==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/relay/kotlin/HybridConnectionAuthorizationRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.relay.kotlin

import com.pulumi.azurenative.relay.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.relay.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [HybridConnectionAuthorizationRule].
 */
@PulumiTagMarker
public class HybridConnectionAuthorizationRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: HybridConnectionAuthorizationRuleArgs = HybridConnectionAuthorizationRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend HybridConnectionAuthorizationRuleArgsBuilder.() -> Unit) {
        val builder = HybridConnectionAuthorizationRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): HybridConnectionAuthorizationRule {
        val builtJavaResource =
            com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return HybridConnectionAuthorizationRule(builtJavaResource)
    }
}

/**
 * Single item in a List or Get AuthorizationRule operation
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2017-04-01.
 * Other available API versions: 2017-04-01.
 * ## Example Usage
 * ### RelayHybridConnectionAuthorizationRuleCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var hybridConnectionAuthorizationRule = new AzureNative.Relay.HybridConnectionAuthorizationRule("hybridConnectionAuthorizationRule", new()
 *     {
 *         AuthorizationRuleName = "example-RelayAuthRules-01",
 *         HybridConnectionName = "example-Relay-Hybrid-01",
 *         NamespaceName = "example-RelayNamespace-01",
 *         ResourceGroupName = "resourcegroup",
 *         Rights = new[]
 *         {
 *             "Listen",
 *             "Send",
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/relay/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := relay.NewHybridConnectionAuthorizationRule(ctx, "hybridConnectionAuthorizationRule", &relay.HybridConnectionAuthorizationRuleArgs{
 * 			AuthorizationRuleName: pulumi.String("example-RelayAuthRules-01"),
 * 			HybridConnectionName:  pulumi.String("example-Relay-Hybrid-01"),
 * 			NamespaceName:         pulumi.String("example-RelayNamespace-01"),
 * 			ResourceGroupName:     pulumi.String("resourcegroup"),
 * 			Rights: pulumi.StringArray{
 * 				pulumi.String("Listen"),
 * 				pulumi.String("Send"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule;
 * import com.pulumi.azurenative.relay.HybridConnectionAuthorizationRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var hybridConnectionAuthorizationRule = new HybridConnectionAuthorizationRule("hybridConnectionAuthorizationRule", HybridConnectionAuthorizationRuleArgs.builder()
 *             .authorizationRuleName("example-RelayAuthRules-01")
 *             .hybridConnectionName("example-Relay-Hybrid-01")
 *             .namespaceName("example-RelayNamespace-01")
 *             .resourceGroupName("resourcegroup")
 *             .rights(
 *                 "Listen",
 *                 "Send")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:relay:HybridConnectionAuthorizationRule example-RelayAuthRules-01 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Relay/namespaces/{namespaceName}/hybridConnections/{hybridConnectionName}/authorizationRules/{authorizationRuleName}
 * ```
 */
public class HybridConnectionAuthorizationRule internal constructor(
    override val javaResource: com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule,
) : KotlinCustomResource(javaResource, HybridConnectionAuthorizationRuleMapper) {
    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The rights associated with the rule.
     */
    public val rights: Output<List<String>>
        get() = javaResource.rights().applyValue({ args0 -> args0.map({ args0 -> args0 }) })

    /**
     * The system meta data relating to this resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object HybridConnectionAuthorizationRuleMapper :
    ResourceMapper<HybridConnectionAuthorizationRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule::class == javaResource::class

    override fun map(javaResource: Resource): HybridConnectionAuthorizationRule =
        HybridConnectionAuthorizationRule(
            javaResource as
                com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule,
        )
}

/**
 * @see [HybridConnectionAuthorizationRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [HybridConnectionAuthorizationRule].
 */
public suspend fun hybridConnectionAuthorizationRule(
    name: String,
    block: suspend HybridConnectionAuthorizationRuleResourceBuilder.() -> Unit,
):
    HybridConnectionAuthorizationRule {
    val builder = HybridConnectionAuthorizationRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [HybridConnectionAuthorizationRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun hybridConnectionAuthorizationRule(name: String): HybridConnectionAuthorizationRule {
    val builder = HybridConnectionAuthorizationRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/relay/kotlin/HybridConnectionAuthorizationRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.relay.kotlin

import com.pulumi.azurenative.relay.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.relay.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [HybridConnectionAuthorizationRule].
 */
@PulumiTagMarker
public class HybridConnectionAuthorizationRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: HybridConnectionAuthorizationRuleArgs = HybridConnectionAuthorizationRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend HybridConnectionAuthorizationRuleArgsBuilder.() -> Unit) {
        val builder = HybridConnectionAuthorizationRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): HybridConnectionAuthorizationRule {
        val builtJavaResource =
            com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return HybridConnectionAuthorizationRule(builtJavaResource)
    }
}

/**
 * Single item in a List or Get AuthorizationRule operation
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2017-04-01.
 * Other available API versions: 2017-04-01.
 * ## Example Usage
 * ### RelayHybridConnectionAuthorizationRuleCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var hybridConnectionAuthorizationRule = new AzureNative.Relay.HybridConnectionAuthorizationRule("hybridConnectionAuthorizationRule", new()
 *     {
 *         AuthorizationRuleName = "example-RelayAuthRules-01",
 *         HybridConnectionName = "example-Relay-Hybrid-01",
 *         NamespaceName = "example-RelayNamespace-01",
 *         ResourceGroupName = "resourcegroup",
 *         Rights = new[]
 *         {
 *             AzureNative.Relay.AccessRights.Listen,
 *             AzureNative.Relay.AccessRights.Send,
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/relay/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := relay.NewHybridConnectionAuthorizationRule(ctx, "hybridConnectionAuthorizationRule", &relay.HybridConnectionAuthorizationRuleArgs{
 * 			AuthorizationRuleName: pulumi.String("example-RelayAuthRules-01"),
 * 			HybridConnectionName:  pulumi.String("example-Relay-Hybrid-01"),
 * 			NamespaceName:         pulumi.String("example-RelayNamespace-01"),
 * 			ResourceGroupName:     pulumi.String("resourcegroup"),
 * 			Rights: pulumi.StringArray{
 * 				pulumi.String(relay.AccessRightsListen),
 * 				pulumi.String(relay.AccessRightsSend),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule;
 * import com.pulumi.azurenative.relay.HybridConnectionAuthorizationRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var hybridConnectionAuthorizationRule = new HybridConnectionAuthorizationRule("hybridConnectionAuthorizationRule", HybridConnectionAuthorizationRuleArgs.builder()
 *             .authorizationRuleName("example-RelayAuthRules-01")
 *             .hybridConnectionName("example-Relay-Hybrid-01")
 *             .namespaceName("example-RelayNamespace-01")
 *             .resourceGroupName("resourcegroup")
 *             .rights(
 *                 "Listen",
 *                 "Send")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:relay:HybridConnectionAuthorizationRule example-RelayAuthRules-01 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Relay/namespaces/{namespaceName}/hybridConnections/{hybridConnectionName}/authorizationRules/{authorizationRuleName}
 * ```
 */
public class HybridConnectionAuthorizationRule internal constructor(
    override val javaResource: com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule,
) : KotlinCustomResource(javaResource, HybridConnectionAuthorizationRuleMapper) {
    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The rights associated with the rule.
     */
    public val rights: Output<List<String>>
        get() = javaResource.rights().applyValue({ args0 -> args0.map({ args0 -> args0 }) })

    /**
     * The system meta data relating to this resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object HybridConnectionAuthorizationRuleMapper :
    ResourceMapper<HybridConnectionAuthorizationRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule::class == javaResource::class

    override fun map(javaResource: Resource): HybridConnectionAuthorizationRule =
        HybridConnectionAuthorizationRule(
            javaResource as
                com.pulumi.azurenative.relay.HybridConnectionAuthorizationRule,
        )
}

/**
 * @see [HybridConnectionAuthorizationRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [HybridConnectionAuthorizationRule].
 */
public suspend fun hybridConnectionAuthorizationRule(
    name: String,
    block: suspend HybridConnectionAuthorizationRuleResourceBuilder.() -> Unit,
):
    HybridConnectionAuthorizationRule {
    val builder = HybridConnectionAuthorizationRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [HybridConnectionAuthorizationRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun hybridConnectionAuthorizationRule(name: String): HybridConnectionAuthorizationRule {
    val builder = HybridConnectionAuthorizationRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}
